@@ -11,11 +11,11 @@ PGObject::Util::PGConfig - Postgres Configuration Management
 
 =head1 VERSION
 
-Version 0.10.2
+Version 0.20
 
 =cut
 
-our $VERSION = 0.010002;
+our $VERSION = 0.020000;
 
 
 =head1 SYNOPSIS
@@ -193,6 +193,45 @@ sub sync_session{
     }
 }
 
+=head2 apply_system($dbh)
+
+Requires superuser access.  Runs ALTER SYSTEM commands for all appropriate
+keys.
+
+Returns a list of keys applied.  This can then be used to check against
+expected behavior.
+
+=cut
+
+sub apply_system {
+    my ($self, $dbh) = @_;
+    croak 'Need a database handle' unless ref $dbh;
+    my $sth = $dbh->prepare('
+          select rolsuper from pg_roles where rolname = session_user
+    ');
+    $sth->execute();
+    if (! ($sth->fetchrow_array)[0]){
+        croak 'DB connection for apply_system must be for a superuser';
+    }
+    my $setting_sth = $dbh->prepare("
+      select name from pg_settings where name = any(?)
+      and context <> 'internal'
+    ");
+    $setting_sth->execute([$self->known_keys]);
+    my @settings;
+    while (my ($setting) = $setting_sth->fetchrow_array){
+       push @settings, $setting;
+    }
+    $setting_sth->finish;
+    for (@settings){
+        my $key = $dbh->quote_identifier($_);
+        my $value = $dbh->quote($self->get_value($_));
+        $dbh->do("ALTER SYSTEM SET $key TO $value");
+    } 
+    return @settings;
+    
+}
+
 =head2 File and Contents
 
 This module is also capable of reading to and writing to files
@@ -273,7 +312,7 @@ Writes the contents, per filecontents above, to $path
 sub tofile {
     my ($self, $path) = @_;
     my $fh;
-    open $fh, '>', $path;
+    open($fh, '>', $path) or die $!;
     print $fh $self->filecontents;
     close $fh;
 }
